==> nautilus-0.5.tar.gz: nautilus-0.5/components/services/trilobite/libtrilobite/libtrilobite.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* 
 * Copyright (C) 2000 Eazel, Inc
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Authors: J Shane Culpepper <pepper@eazel.com>
 *
 */

/*
 * libtrilobite - Useful functions shared between all services.  This
 * includes things like xml parsing, logging, error control, and others.
 *
 */

#ifndef __LIBTRILOBITE_H__
#define __LIBTRILOBITE_H__

#include <gnome.h>

#include "trilobite-core-messaging.h"
#include "trilobite-core-utils.h"
#include "trilobite-core-network.h"
#include "trilobite-core-package-manager.h"
#include "trilobite-core-security-manager.h"
#include "trilobite-core-metadata-manager.h"
#include "trilobite-core-tests.h"
#include "trilobite-root-helper.h"
#include "trilobite-redirect.h"
#include "helixcode-utils.h"
#include "trilobite-root-client-public.h"

#endif /* __LIBTRILOBITE_H__ */

/*********************** end libtrilobite.h ***********************************/

==> nautilus-1.0.1.1.tar.gz: nautilus-1.0.1.1/components/services/trilobite/libtrilobite/libtrilobite.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* 
 * Copyright (C) 2000 Eazel, Inc
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Authors: J Shane Culpepper <pepper@eazel.com>
 *
 */

/*
 * libtrilobite - Useful functions shared between all services.  This
 * includes things like xml parsing, logging, error control, and others.
 *
 */

#ifndef __LIBTRILOBITE_H__
#define __LIBTRILOBITE_H__

#include <gnome.h>

#include "trilobite-core-messaging.h"
#include "trilobite-core-utils.h"
#include "trilobite-core-distribution.h"
#include "trilobite-core-network.h"
#include "trilobite-root-helper.h"
#include "trilobite-redirect.h"
#include "trilobite-root-client-public.h"

#endif /* __LIBTRILOBITE_H__ */

/*********************** end libtrilobite.h ***********************************/
